@@ -5,10 +5,10 @@ BondType = Generate_New_Bonded_Force_Type("bond", "1-2", {"k":float, "b":float},
 BondType.Set_Property_Unit("k", "energy·distance^-2", "kcal/mol·A^-2")
 BondType.Set_Property_Unit("b", "distance", "A")
 
-@Molecule.Set_Save_SPONGE_Input
-def write_bond(self, prefix, dirname):
+@Molecule.Set_Save_SPONGE_Input("bond")
+def write_bond(self):
     bonds = []
-    for bond in self.bonded_forces["bond"]:
+    for bond in self.bonded_forces.get("bond",[]):
         order = list(range(2))
         if bond.k != 0:
             if self.atom_index[bond.atoms[order[0]]] > self.atom_index[bond.atoms[order[-1]]]:
@@ -23,6 +23,4 @@ def write_bond(self, prefix, dirname):
         bonds.sort(key = lambda x: list(map(int, x.split()[:2])))
         towrite += "\n".join(bonds)
         
-        f = open(os.path.join(dirname, prefix + "_bond.txt"),"w")
-        f.write(towrite)
-        f.close()
\ No newline at end of file
+        return towrite
\ No newline at end of file
