@@ -3,7 +3,7 @@ from ... import *
 
 def write_mass(self):
     towrite = "%d\n"%(len(self.atoms))
-    towrite += "\n".join(["%.3f"%(0.1) if (atom.mass < 3.999 or atom.LJtype == "ZERO_LJ_ATOM") else "%.3f"%(100) for atom in self.atoms])
+    towrite += "\n".join(["%.3f"%(1) if (atom.mass < 3.999 or atom.LJtype == "ZERO_LJ_ATOM") else "%.3f"%(0) for atom in self.atoms])
     return towrite
 
 
