@@ -482,22 +482,20 @@ def mol2rfe(args):
                 cif = "-coordinate_in_file {1}/min/{0}_coordinate.txt".format(args.temp, i-1)
             else:
                 cif = ""
-                os.rename("0/{0}_LJ_soft_core.txt".format(args.temp), "0/{0}_lj_soft_core.txt".format(args.temp))
-                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5} {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[0]))
+                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5} {4} -mass_in_file {2}/{1}_fake_mass.txt -lambda_lj {3}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[0]))
                 cif = "-coordinate_in_file {1}/min/{0}_coordinate.txt".format(args.temp, i)
-                os.system("{0} -mode minimization -dt 1e-7 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[1]))
-                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[0]))
-                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[1]))
-                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[2]))
-                os.rename("0/{0}_lj_soft_core.txt".format(args.temp), "0/{0}_LJ_soft_core.txt".format(args.temp))
-                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} {4} constrain_mode SHAKE".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[0]))
-                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[0]))
-                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[1]))
-                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[2]))
-                os.system("{0} -mode minimization -dt 1e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m3steps[3]))
+                os.system("{0} -mode minimization -dt 1e-7 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt -lambda_lj {3}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[1]))
+                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt -lambda_lj {3}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[2]))
+                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt -lambda_lj {3}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[3]))
+                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -step_limit {5}  {4} -mass_in_file {2}/{1}_fake_mass.txt -lambda_lj {3}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m1steps[4]))
+                os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5}  {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[0]))
+                os.system("{0} -mode minimization -dt 1e-7 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5}  {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[1]))
+                os.system("{0} -mode minimization -dt 1e-6 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5}   {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[2]))
+                os.system("{0} -mode minimization -dt 1e-5 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5}   {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[3]))
+                os.system("{0} -mode minimization -dt 1e-4 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5}   {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.m2steps[4]))
 
             os.system("{0} -mode minimization -minimization_dynamic_dt 1 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} {4} constrain_mode SHAKE".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[0]))
-            os.system("{0} -mode minimization -dt 2e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[1]))
+            os.system("{0} -mode minimization -dt 1e-3 -default_in_file_prefix {2}/{1} -mdinfo {2}/min/{1}.mdinfo -mdout {2}/min/{1}.mdout -rst {2}/min/{1} -crd {2}/min/{1}.dat -box {2}/min/{1}.box -lambda_lj {3} -step_limit {5} -constrain_mode SHAKE {4}".format(args.sponge, args.temp, i, i / args.nl, cif, args.msteps[1]))
 
     if "prebalance" in args.do:
         for i in range(args.nl + 1):
